/* plugin.h
 *
 * hashkill - a hash cracking tool
 * Copyright (C) 2010 Milen Rangelov <gat3way@gat3way.eu>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */


#ifndef PLUGIN_H
#define PLUGIN_H

#include "err.h"

void *(*hash_add_username)(const char *username);
void *(*hash_add_hash)(const char *hash);
void *(*hash_add_salt)(const char *salt);
void *(*hash_add_salt2)(const char *salt2);
void *(*hash_md5)(const char *plaintext, char *hash, int len);
void *(*hash_md5_hex)(const char *hash,  char *hashhex);
void *(*hash_sha1)(const char *plaintext, char *hash, int len);
void *(*hash_sha1_hex)(const char *hash, char *hashhex);
void *(*hash_sha1)(const char *plaintext, char *hash, int len);
void *(*hash_sha1_hex)(const char *hash, char *hashhex);
void *(*hash_sha256)(const char *plaintext, char *hash, int len);
void *(*hash_sha256_hex)(const char *hash, char *hashhex);
void *(*hash_sha512)(const char *plaintext, char *hash, int len);
void *(*hash_sha512_hex)(const char *hash, char *hashhex);
void *(*hash_fcrypt)(const char *password, const char *salt, char *ret);

void register_add_username(void *(*add_username)(const char *username));
void register_add_hash(void *(*add_hash)(const char *hash));
void register_add_salt(void *(*add_salt)(const char *salt));
void register_add_salt2(void *(*add_salt2)(const char *salt2));
void register_md5(void *(*md5)(const char *plaintext, char *hash, int len));
void register_md5_hex(void *(*md5_hex)(const char *hash, char *hashhex));
void register_sha1(void *(*sha1)(const char *plaintext, char *hash, int len));
void register_sha1_hex(void *(*sha1_hex)(const char *hash, char *hashhex));
void register_sha256(void *(*sha256)(const char *plaintext, char *hash, int len));
void register_sha256_hex(void *(*sha256_hex)(const char *hash, char *hashhex));
void register_sha512(void *(*sha512)(const char *plaintext, char *hash, int len));
void register_sha512_hex(void *(*sha512_hex)(const char *hash, char *hashhex));
void register_fcrypt(void *(*hfcrypt)(const char *password, const char *salt, char *ret));

int fastcompare(const char *s1, const char *s2, int length);
char* strupr(char* ioString);
char* strlow(char* ioString);

#endif
