/* smf.c
 *
 * hashkill - a hash cracking tool
 * Copyright (C) 2010 Milen Rangelov <gat3way@gat3way.eu>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */


#include <stdio.h>
#include <unistd.h>
#include <string.h>
#include <alloca.h>
#include "plugin.h"
#include "err.h"
#include "hashinterface.h"


char * hash_plugin_summary(void)
{
    return("smf \t\tSMF plugin");
}


char * hash_plugin_detailed(void)
{
    return("smf - SMF password hashes plugin\n"
	    "-------------------------------\n"
	    "Use this module to crack SMF hashes\n"
	    "Input should be in form: \'user:hash\'\n"
	    "Known software that uses this password hashing method:\n"
	    "Simple Machines Forum (SMF) \n"
	    "\nAuthor: Milen Rangelov <gat3way@gat3way.eu>\n");
}


hash_stat hash_plugin_parse_hash(char *hashline)
{
    char username[HASHFILE_MAX_LINE_LENGTH];
    char hash[HASHFILE_MAX_LINE_LENGTH];
    char line[HASHFILE_MAX_LINE_LENGTH];
    char *temp_str;
    
    if (!hashline) return hash_err;
    
    if (strlen(hashline)<2) return hash_err;
    
    snprintf(line, HASHFILE_MAX_LINE_LENGTH-1, "%s", hashline);
    strcpy(username, strtok(line, ":"));
    temp_str=strtok(NULL,":");
    if (temp_str) 
    {
	strcpy(hash, temp_str);
    }

    /* Hash is not 40 characters long => not a smf hash */
    if (strlen(hash)!=40)
    {
	return hash_err;
    }
    
    /* No hash provided at all */
    if (strcmp(username,hashline)==0)
    {
	return hash_err;
    }
    
    (void)hash_add_username(username);
    (void)hash_add_hash(hash);
    (void)hash_add_salt("   ");
    (void)hash_add_salt2("");

    return hash_ok;
}


hash_stat hash_plugin_check_hash(const char *hash, const char *password, const char *salt,  char *salt2, const char *username)
{
    char hash1[HASHFILE_MAX_LINE_LENGTH];
    char *hash2;
    char *hash3;
    hash2 = alloca(HASHFILE_MAX_LINE_LENGTH);
    hash3 = alloca(HASHFILE_MAX_LINE_LENGTH);

    hash1[0] = 0;
    bzero(hash2,100);
    strcpy(hash2, username);
    strlow(hash2);
    strcat(hash1, hash2);
    strcat(hash1, password);
    
    (void)hash_sha1(hash1, hash2, strlen(hash1));
    (void)hash_sha1_hex(hash2, salt2);

    if (strcmp(salt2, hash)==0) {return hash_ok;}
    else return hash_err;
}


int hash_plugin_hash_length(void)
{
    return 0;
}
